simplify.PaymentsApi

Package simplify :: Class PaymentsApi |
[hide private]
[frames] | no frames]

# Class PaymentsApi

source code

Instance Methods | [hide private]
__init__(self) | source code
decode(self, auth_args, params) | source code
execute(self, object_type, auth, url_suffix, method, params=None) | source code
send_auth_request(self, props, context, auth) | source code
get_oauth_error(self, msg, error_code, error_desc) | source code

Class Methods | [hide private]
build_request_url(cls, object_type, object_id='') | source code

Static Methods | [hide private]
create_auth_object(auth_args) | source code
check_auth(auth) | source code
create(object_type, auth_args, params) | source code
list(object_type, auth_args, criteria) | source code
find(object_type, auth_args, object_id) | source code
update(object_type, auth_args, object_id, params) | source code
delete(object_type, auth_args, object_id) | source code